@@ -21,7 +21,12 @@
  * THE SOFTWARE.
  */
 
-#include <lite/lite.h>
+#ifdef _LIBITE_LITE
+# include <libite/lite.h>
+#else
+# include <lite/lite.h>
+#endif
+
 #include "finit.h"
 #include "helpers.h"
 #include "plugin.h"
