@@ -40,11 +40,15 @@
 #include <sys/stat.h>
 #include <sys/time.h>		/* gettimeofday() */
 #include <sys/types.h>
-#include <lite/lite.h>
+#ifdef _LIBITE_LITE
+# include <libite/lite.h>
+#else
+# include <lite/lite.h>
+#endif
 
 #include "config.h"
 #include "finit.h"
-#include "helpers.h"
+#include "util.h"
 #include "plugin.h"
 
 struct module {
