@@ -24,7 +24,11 @@
 #include <time.h>
 #include <sys/ioctl.h>
 #include <linux/rtc.h>
-#include <lite/lite.h>
+#ifdef _LIBITE_LITE
+# include <libite/lite.h>
+#else
+# include <lite/lite.h>
+#endif
 
 #include "finit.h"
 #include "helpers.h"
@@ -152,8 +156,18 @@ static void rtc_restore(void *arg)
 			logit(LOG_ERR, "RTC has no previously saved (valid) time.");
 		else
 			logit(LOG_ERR, "RTC error code %d: %s", errno, strerror(errno));
+
+		/* Been here already? */
+		if (rc)
+			goto out;
+
+		/* Attempt to set RTC to a sane value ... */
+		tv.tv_sec = RTC_TIMESTAMP_BEGIN_2000;
+		if (!gmtime_r(&tv.tv_sec, &tm))
+			goto out;
+
+		logit(LOG_NOTICE, "Resetting RTC to kernel default, 2000-01-01 00:00.");
 		rc = 2;
-		goto out;
 	}
 
 	print_desc(NULL, "Restoring system clock (UTC) from RTC");
