@@ -27,7 +27,11 @@
 #include <unistd.h>		/* read() */
 #include <sys/inotify.h>
 #include <sys/stat.h>
-#include <lite/lite.h>
+#ifdef _LIBITE_LITE
+# include <libite/lite.h>
+#else
+# include <lite/lite.h>
+#endif
 
 #include "finit.h"
 #include "helpers.h"
