@@ -29,7 +29,11 @@
 #include <unistd.h>
 #include <sys/socket.h>
 #include <sys/un.h>
-#include <lite/lite.h>
+#ifdef _LIBITE_LITE
+# include <libite/lite.h>
+#else
+# include <lite/lite.h>
+#endif
 #include <uev/uev.h>
 
 #include "config.h"
@@ -387,7 +391,7 @@ static void api_cb(uev_t *w, void *arg, int events)
 				break;
 			}
 
-			_e("Request to hand-over wdog ... to PID %d", rq.runlevel);
+			_d("Request to hand-over wdog ... to PID %d", rq.runlevel);
 			svc = svc_find_by_pid(rq.runlevel);
 			if (!svc) {
 				logit(LOG_ERR, "Cannot find PID %d, not registered.", rq.runlevel);
@@ -413,7 +417,7 @@ static void api_cb(uev_t *w, void *arg, int events)
 		case INIT_CMD_SVC_ITER:
 //			_d("svc iter, first: %d", rq.runlevel);
 			/*
-			 * XXX: This severly limits the number of
+			 * XXX: This severely limits the number of
 			 * simultaneous client connections, but will
 			 * have to do for now.
 			 */
@@ -466,12 +470,13 @@ error:
 
 int api_init(uev_ctx_t *ctx)
 {
-	int sd;
-	mode_t oldmask;
 	struct sockaddr_un sun = {
 		.sun_family = AF_UNIX,
 		.sun_path   = INIT_SOCKET,
 	};
+	mode_t oldmask;
+	int uid, gid;
+	int sd;
 
 	_d("Setting up external API socket ...");
 	sd = socket(AF_UNIX, SOCK_SEQPACKET | SOCK_CLOEXEC, 0);
@@ -480,20 +485,26 @@ int api_init(uev_ctx_t *ctx)
 		return 1;
 	}
 
+	uid = geteuid();
+	gid = getgroup(DEFGROUP);
+
 	erase(INIT_SOCKET);
-	oldmask = umask(0077);
+	oldmask = umask(0117);
 	if (-1 == bind(sd, (struct sockaddr*)&sun, sizeof(sun)))
 		goto error;
 
 	if (-1 == listen(sd, 10))
 		goto error;
 
+	if (chown(INIT_SOCKET, uid, gid))
+		_pe("Failed setting group %s on %s", DEFGROUP, INIT_SOCKET);
+
 	umask(oldmask);
 	if (!uev_io_init(ctx, &api_watcher, api_cb, NULL, sd, UEV_READ))
 		return 0;
 
 error:
-	_pe("Failed intializing API socket");
+	_pe("Failed initializing API socket");
 	umask(oldmask);
 	close(sd);
 	return 1;
