@@ -24,8 +24,13 @@
 #include <errno.h>
 #include <stdio.h>
 #include <string.h>
-#include <lite/lite.h>
-#include <lite/queue.h>
+#ifdef _LIBITE_LITE
+# include <libite/lite.h>
+# include <libite/queue.h>	/* BSD sys/queue.h API */
+#else
+# include <lite/lite.h>
+# include <lite/queue.h>	/* BSD sys/queue.h API */
+#endif
 #include <sys/mount.h>
 #include <sys/sysinfo.h>		/* get_nprocs_conf() */
 
@@ -42,7 +47,7 @@ struct cg {
 	char *cfg;		/* kernel settings */
 
 	int  active;		/* for mark & sweep */
-	int  protected;		/* for init/, user/, & system/ */
+	int  is_protected;	/* for init/, user/, & system/ */
 };
 
 static TAILQ_HEAD(, cg) cgroups = TAILQ_HEAD_INITIALIZER(cgroups);
@@ -51,6 +56,7 @@ static char controllers[256];
 
 static struct iwatch iw_cgroup;
 static uev_t cgw;
+static int avail;
 
 
 static void cgset(const char *path, char *ctrl, char *prop)
@@ -159,6 +165,9 @@ static int cgroup_leaf_init(char *group, char *name, int pid, const char *cfg)
 
 int cgroup_user(char *name, int pid)
 {
+	if (!avail)
+		return 0;
+
 	return cgroup_leaf_init("user", name, pid, NULL);
 }
 
@@ -166,6 +175,9 @@ int cgroup_service(char *name, int pid, struct cgroup *cg)
 {
 	char *group = "system";
 
+	if (!avail)
+		return 0;
+
 	if (cg && cg->name[0]) {
 		char path[256];
 
@@ -302,8 +314,11 @@ void cgroup_mark_all(void)
 {
 	struct cg *cg;
 
+	if (!avail)
+		return;
+
 	TAILQ_FOREACH(cg, &cgroups, link) {
-		if (cg->protected)
+		if (cg->is_protected)
 			continue;
 
 		cg->active = 0;
@@ -318,6 +333,9 @@ void cgroup_cleanup(void)
 	struct cg *cg, *tmp;
 	char path[256];
 
+	if (!avail)
+		return;
+
 	TAILQ_FOREACH_SAFE(cg, &cgroups, link, tmp) {
 		if (cg->active)
 			continue;
@@ -330,10 +348,13 @@ void cgroup_cleanup(void)
 /*
  * Add, or update, settings for top-level cgroup
  */
-int cgroup_add(char *name, char *cfg, int protected)
+int cgroup_add(char *name, char *cfg, int is_protected)
 {
 	struct cg *cg;
 
+	if (!avail)
+		return 0;
+
 	if (!name)
 		return -1;
 	if (!cfg)
@@ -364,7 +385,7 @@ int cgroup_add(char *name, char *cfg, int protected)
 		free(cg);
 		return -1;
 	}
-	cg->protected = protected;
+	cg->is_protected = is_protected;
 	cg->active = 1;
 
 	return 0;
@@ -378,6 +399,9 @@ int cgroup_del(char *dir)
 	struct cg *cg;
 	char path[256];
 
+	if (!avail)
+		return 0;
+
 	TAILQ_FOREACH(cg, &cgroups, link) {
 		snprintf(path, sizeof(path), FINIT_CGPATH "/%s", cg->name);
 		if (strcmp(path, dir))
@@ -409,6 +433,9 @@ void cgroup_config(void)
 {
 	struct cg *cg;
 
+	if (!avail)
+		return;
+
 	TAILQ_FOREACH(cg, &cgroups, link) {
 		char path[256];
 		int leaf = 0;
@@ -437,14 +464,21 @@ void cgroup_init(uev_ctx_t *ctx)
 	int fd;
 
 	if (mount("none", FINIT_CGPATH, "cgroup2", opts, NULL)) {
-		_pe("Failed mounting cgroup v2");
+		if (errno == ENOENT)
+			logit(LOG_NOTICE, "Kernel does not support cgroups v2, disabling.");
+		else
+			_pe("Failed mounting cgroup v2, disabling.");
+		avail = 0;
 		return;
 	}
+	avail = 1;
 
 	/* Find available controllers */
 	fp = fopen(FINIT_CGPATH "/cgroup.controllers", "r");
 	if (!fp) {
 		_pe("Failed opening %s", FINIT_CGPATH "/cgroup.controllers");
+		umount(FINIT_CGPATH);
+		avail = 0;
 		return;
 	}
 
