@@ -23,8 +23,12 @@
 
 #include <ftw.h>
 #include <libgen.h>
-#include <lite/lite.h>
 #include <stdio.h>
+#ifdef _LIBITE_LITE
+# include <libite/lite.h>
+#else
+# include <lite/lite.h>
+#endif
 
 #include "finit.h"
 #include "cond.h"
@@ -273,7 +277,7 @@ static int do_assert(const char *fpath, const struct stat *sb, int tflg, struct
 
 	nm = strstr((char *)fpath, COND_BASE);
 	if (!nm) {
-		_e("Incorrect condtion path %s, cannot %sassert", fpath, set ? "re" : "de");
+		_e("Incorrect condition path %s, cannot %sassert", fpath, set ? "re" : "de");
 		return 1;
 	}
 
