@@ -21,8 +21,12 @@
  * THE SOFTWARE.
  */
 
-#include <lite/lite.h>
 #include <stdio.h>
+#ifdef _LIBITE_LITE
+# include <libite/lite.h>
+#else
+# include <lite/lite.h>
+#endif
 
 #include "finit.h"
 #include "cond.h"
