@@ -34,7 +34,11 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <unistd.h>
-#include <lite/lite.h>
+#ifdef _LIBITE_LITE
+# include <libite/lite.h>
+#else
+# include <lite/lite.h>
+#endif
 #include <uev/uev.h>
 
 /* just in case */
@@ -110,6 +114,7 @@ extern int    debug;
 extern int    rescue;
 extern int    single;
 extern int    bootstrap;
+extern int    kerndebug;
 extern char  *rcsd;
 extern char  *sdown;
 extern char  *network;
