@@ -31,7 +31,11 @@
 #include <netinet/in.h>
 #include <stdarg.h>
 #include <sys/ioctl.h>
-#include <lite/lite.h>
+#ifdef _LIBITE_LITE
+# include <libite/lite.h>
+#else
+# include <lite/lite.h>
+#endif
 
 #include "finit.h"
 #include "helpers.h"
@@ -223,7 +227,7 @@ void print_banner(const char *heading)
 		return;
 
 	buf[0] = 0;
-	strlcat(buf, "\r\e[2K", sizeof(buf));
+	strlcat(buf, "\r\e[K", sizeof(buf));
 
 	if (progress_style == PROGRESS_CLASSIC) {
 		strlcat(buf, "\e[1m", sizeof(buf));
@@ -308,7 +312,7 @@ void printv(const char *fmt, va_list ap)
 	if (progress_style == PROGRESS_CLASSIC)
 		cprintf("\r%s ", pad(buf, sizeof(buf), ".", sizeof(buf)));
 	else
-		cprintf("\r\e[2K%s%s", status(3), buf);
+		cprintf("\r\e[K%s%s", status(3), buf);
 }
 
 void print(int rc, const char *fmt, ...)
@@ -560,55 +564,6 @@ void endfsent(void)
 }
 #endif	/* HAVE_GETFSENT */
 
-static int hasopt(char *opts, char *opt)
-{
-	char buf[strlen(opts) + 1];
-	char *ptr;
-
-	memcpy(buf, opts, sizeof(buf));
-	ptr = strtok(buf, ",");
-	while (ptr) {
-		if (!strcmp(ptr, opt))
-			return 1;
-
-		ptr = strtok(NULL, ",");
-	}
-
-	return 0;
-}
-
-int ismnt(char *file, char *dir, char *mode)
-{
-	struct mntent *mnt;
-	int found = 0;
-	FILE *fp;
-
-	fp = setmntent(file, "r");
-	if (!fp)
-		return 0;	/* Dunno, maybe not */
-
-	while ((mnt = getmntent(fp))) {
-		if (!strcmp(mnt->mnt_dir, dir)) {
-			if (mode) {
-				if (hasopt(mnt->mnt_opts, mode))
-					found = 1;
-			} else
-				found = 1;
-
-			break;
-		}
-	}
-	endmntent(fp);
-
-	return found;
-}
-
-/* Requires /proc to be mounted */
-int fismnt(char *dir)
-{
-	return ismnt("/proc/mounts", dir, NULL);
-}
-
 /**
  * Local Variables:
  *  indent-tabs-mode: t
