@@ -32,7 +32,11 @@
 #include <sys/types.h>
 #include <sys/ttydefaults.h>	/* Not included by default in musl libc */
 #include <termios.h>
-#include <lite/lite.h>
+#ifdef _LIBITE_LITE
+# include <libite/lite.h>
+#else
+# include <lite/lite.h>
+#endif
 #include "log.h"
 
 #define PROGRESS_DEFAULT PROGRESS_MODERN
@@ -126,9 +130,6 @@ static inline int dprint(int fd, const char *s, size_t len)
 	return rc;
 }
 
-int	ismnt		(char *file, char *dir, char *mode);
-int	fismnt		(char *dir);
-
 #endif /* FINIT_HELPERS_H_ */
 
 /**
