@@ -33,7 +33,11 @@
 #include <time.h>
 #include <utmp.h>
 #include <arpa/inet.h>
-#include <lite/lite.h>
+#ifdef _LIBITE_LITE
+# include <libite/lite.h>
+#else
+# include <lite/lite.h>
+#endif
 
 #include "client.h"
 #include "cond.h"
@@ -47,6 +51,7 @@ struct cmd {
 	char        *cmd;
 	struct cmd  *ctx;
 	int        (*cb)(char *arg);
+	int         *cond;
 };
 
 int icreate  = 0;
@@ -58,6 +63,9 @@ int verbose  = 0;
 int plain    = 0;
 int quiet    = 0;
 int runlevel = 0;
+int cgrp     = 0;
+int utmp     = 0;
+
 int iw, pw;
 
 extern int reboot_main(int argc, char *argv[]);
@@ -167,11 +175,11 @@ static int do_runlevel(char *arg)
 
 	if (!arg) {
 		int prevlevel = 0;
-		int runlevel;
+		int currlevel;
 		char prev;
 
-		runlevel = runlevel_get(&prevlevel);
-		if (255 == runlevel) {
+		currlevel = runlevel_get(&prevlevel);
+		if (255 == currlevel) {
 			printf("unknown\n");
 			return 0;
 		}
@@ -180,7 +188,7 @@ static int do_runlevel(char *arg)
 		if (prev <= '0' || prev > '9')
 			prev = 'N';
 
-		printf("%c %d\n", prev , runlevel);
+		printf("%c %d\n", prev , currlevel);
 		return 0;
 	}
 
@@ -468,15 +476,12 @@ int do_suspend (char *arg) { return do_cmd(INIT_CMD_SUSPEND);  }
 
 int utmp_show(char *file)
 {
-	static int once = 0;
-	struct tm *sectm;
 	struct utmp *ut;
 	time_t sec;
 
-	int pid;
-	char id[sizeof(ut->ut_id) + 1], user[sizeof(ut->ut_user) + 1], when[80];
-
 	if (heading) {
+		static int once = 0;
+
 		print_header("%s%s ", once ? "\n" : "", file);
 		once++;
 	}
@@ -484,7 +489,12 @@ int utmp_show(char *file)
 
 	setutent();
 	while ((ut = getutent())) {
+		char user[sizeof(ut->ut_user) + 1];
+		char id[sizeof(ut->ut_id) + 1];
+		struct tm *sectm;
+		char when[80];
 		char addr[64];
+		int pid;
 
 		strlcpy(id, ut->ut_id, sizeof(id));
 		strlcpy(user, ut->ut_user, sizeof(user));
@@ -509,7 +519,7 @@ int utmp_show(char *file)
 
 static int do_utmp(char *file)
 {
-	if (!has_utmp())
+	if (!utmp)
 		return 1;
 
 	if (fexist(file))
@@ -538,7 +548,7 @@ static int show_version(char *arg)
  * Pointer to string on the form [2345], may be up to 12 chars long,
  * plus escape sequences for highlighting current runlevel.
  */
-char *runlevel_string(int runlevel, int levels)
+char *runlevel_string(int currlevel, int levels)
 {
 	int i, pos = 1;
 	static char lvl[21];
@@ -548,7 +558,7 @@ char *runlevel_string(int runlevel, int levels)
 
 	for (i = 0; i < 10; i++) {
 		if (ISSET(levels, i)) {
-			if (!plain && runlevel == i)
+			if (!plain && currlevel == i)
 				pos = strlcat(lvl, "\e[1m", sizeof(lvl));
 
 			if (i == 0)
@@ -556,7 +566,7 @@ char *runlevel_string(int runlevel, int levels)
 			else
 				lvl[pos++] = '0' + i;
 
-			if (!plain && runlevel == i)
+			if (!plain && currlevel == i)
 				pos = strlcat(lvl, "\e[0m", sizeof(lvl));
 		} else {
 			lvl[pos++] = '-';
@@ -699,17 +709,27 @@ static int show_status(char *arg)
 {
 	char ident[MAX_IDENT_LEN];
 	char buf[512];
+	int num = 0;
 	svc_t *svc;
 
 	runlevel = runlevel_get(NULL);
 
-	if (arg && arg[0]) {
+	while (arg && arg[0]) {
 		long now = jiffies();
 		char uptm[42] = "N/A";
-		char grbuf[128];
-		char path[256];
-		struct cg *cg;
-		char *group;
+		char *pidfn = NULL;
+		int exact = 0;
+
+		for (svc = client_svc_iterator(1); svc; svc = client_svc_iterator(0)) {
+			svc_ident(svc, ident, sizeof(ident));
+			if (string_match(ident, arg))
+				num++;
+			if (string_case_compare(ident, arg))
+				exact++;
+		}
+
+		if (num > 1 && !exact)
+			break;
 
 		svc = client_svc_find(arg);
 		if (!svc)
@@ -718,9 +738,11 @@ static int show_status(char *arg)
 		if (quiet)
 			return svc->state != SVC_RUNNING_STATE;
 
-		group = pid_cgroup(svc->pid, grbuf, sizeof(grbuf));
-		snprintf(path, sizeof(path), "%s/%s", FINIT_CGPATH, group);
-		cg = cg_conf(path);
+		pidfn = svc->pidfile;
+		if (pidfn[0] == '!')
+			pidfn++;
+		else if (pidfn[0] == 0)
+			pidfn = "none";
 
 		printf("     Status : %s\n", status(svc, 1));
 		printf("   Identity : %s\n", svc_ident(svc, ident, sizeof(ident)));
@@ -729,13 +751,23 @@ static int show_status(char *arg)
 		printf("Environment : %s\n", svc_environ(svc, buf, sizeof(buf)));
 		printf("Condition(s): %s\n", svc_cond(svc, buf, sizeof(buf)));
 		printf("    Command : %s\n", svc_command(svc, buf, sizeof(buf)));
-		printf("   PID file : %s\n", svc->pidfile);
+		printf("   PID file : %s\n", pidfn);
 		printf("        PID : %d\n", svc->pid);
 		printf("       User : %s\n", svc->username);
 		printf("      Group : %s\n", svc->group);
 		printf("     Uptime : %s\n", svc->pid ? uptime(now - svc->start_time, uptm, sizeof(uptm)) : uptm);
+		printf("   Restarts : %d (%d/%d)\n", svc->restart_tot, svc->restart_cnt, svc->restart_max);
 		printf("  Runlevels : %s\n", runlevel_string(runlevel, svc->runlevels));
-		if (svc->pid > 1) {
+		if (cgrp && svc->pid > 1) {
+			char grbuf[128];
+			char path[256];
+			struct cg *cg;
+			char *group;
+
+			group = pid_cgroup(svc->pid, grbuf, sizeof(grbuf));
+			snprintf(path, sizeof(path), "%s/%s", FINIT_CGPATH, group);
+			cg = cg_conf(path);
+
 			printf("     Memory : %s\n", memsz(cgroup_memory(group), uptm, sizeof(uptm)));
 			printf("     CGroup : %s cpu %s [%s, %s] mem [%s, %s]\n",
 			       group, cg->cg_cpu.set, cg->cg_cpu.weight, cg->cg_cpu.max,
@@ -764,9 +796,11 @@ static int show_status(char *arg)
 	for (svc = client_svc_iterator(1); svc; svc = client_svc_iterator(0)) {
 		char *lvls;
 
-		printf("%-*d  ", pw, svc->pid);
-
 		svc_ident(svc, ident, sizeof(ident));
+		if (num && !string_match(ident, arg))
+			continue;
+
+		printf("%-*d  ", pw, svc->pid);
 		printf("%-*s  %s ", iw, ident, status(svc, 0));
 
 		lvls = runlevel_string(runlevel, svc->runlevels);
@@ -784,6 +818,30 @@ static int show_status(char *arg)
 	return 0;
 }
 
+static int show_ident(char *arg)
+{
+	svc_t *svc;
+
+	for (svc = client_svc_iterator(1); svc; svc = client_svc_iterator(0)) {
+		char ident[MAX_IDENT_LEN];
+		size_t len;
+		char *pos;
+
+		svc_ident(svc, ident, sizeof(ident));
+		pos = strchr(ident, ':');
+		if (pos)
+			len = pos - ident;
+		else
+			len = strlen(ident);
+		if (arg && arg[0] && strncasecmp(ident, arg, len))
+			continue;
+
+		puts(ident);
+	}
+
+	return 0;
+}
+
 static int transform(char *nm)
 {
 	char *names[] = {
@@ -880,12 +938,16 @@ static int usage(int rc)
 		"  stop     <NAME>[:ID]      Stop/Pause a running service by name\n"
 		"  reload   <NAME>[:ID]      Reload service by name (SIGHUP or restart)\n"
 		"  restart  <NAME>[:ID]      Restart (stop/start) service by name\n"
+		"  ident    [NAME]           Show matching identities for NAME, or all\n"
 		"  status   <NAME>[:ID]      Show service status, by name\n"
-		"  status                    Show status of services, default command\n"
-		"\n"
-		"  cgroup                    List cgroup config overview\n"
-		"  ps                        List processes based on cgroups\n"
-		"  top                       Show top-like listing based on cgroups\n"
+		"  status                    Show status of services, default command\n");
+	if (cgrp)
+		fprintf(stderr,
+			"\n"
+			"  cgroup                    List cgroup config overview\n"
+			"  ps                        List processes based on cgroups\n"
+			"  top                       Show top-like listing based on cgroups\n");
+	fprintf(stderr,
 		"\n"
 		"  runlevel [0-9]            Show or set runlevel: 0 halt, 6 reboot\n"
 		"  reboot                    Reboot system\n"
@@ -893,13 +955,11 @@ static int usage(int rc)
 		"  poweroff                  Halt and power off system\n"
 		"  suspend                   Suspend system\n");
 
-	if (has_utmp())
+	if (utmp)
 		fprintf(stderr,
 			"\n"
-			"  utmp     show             Raw dump of UTMP/WTMP db\n"
-			"\n");
-	else
-		fprintf(stderr, "\n");
+			"  utmp     show             Raw dump of UTMP/WTMP db\n");
+	fprintf(stderr, "\n");
 
 	return rc;
 }
@@ -918,11 +978,22 @@ static int do_help(char *arg)
 	return usage(0);
 }
 
+static int cmd_cond(struct cmd *cmd)
+{
+	if (!cmd || !cmd->cond)
+		return 1;
+
+	return *cmd->cond;
+}
+
 static int cmd_parse(int argc, char *argv[], struct cmd *command)
 {
 	int i, j;
 
 	for (i = 0; argc > 0 && command[i].cmd; i++) {
+		if (!cmd_cond(&command[i]))
+			continue;
+
 		if (!string_match(command[i].cmd, argv[0]))
 			continue;
 
@@ -947,7 +1018,6 @@ static int cmd_parse(int argc, char *argv[], struct cmd *command)
 
 	return command[0].cb(NULL); /* default cmd */
 }
-
 int main(int argc, char *argv[])
 {
 	struct option long_options[] = {
@@ -964,57 +1034,62 @@ int main(int argc, char *argv[])
 		{ NULL, 0, NULL, 0 }
 	};
 	struct cmd cond[] = {
-		{ "status",   NULL, do_cond_show }, /* default cmd */
-		{ "dump",     NULL, do_cond_dump },
-		{ "set",      NULL, do_cond_set  },
-		{ "clr",      NULL, do_cond_clr  },
-		{ "clear",    NULL, do_cond_clr  },
-		{ NULL, NULL, NULL }
+		{ "status",   NULL, do_cond_show, NULL }, /* default cmd */
+		{ "dump",     NULL, do_cond_dump, NULL },
+		{ "set",      NULL, do_cond_set,  NULL },
+		{ "clr",      NULL, do_cond_clr,  NULL },
+		{ "clear",    NULL, do_cond_clr,  NULL },
+		{ NULL, NULL, NULL, NULL }
 	};
 	struct cmd command[] = {
-		{ "status",   NULL, show_status  }, /* default cmd */
+		{ "status",   NULL, show_status,  NULL }, /* default cmd */
+		{ "ident",    NULL, show_ident,   NULL },
 
-		{ "debug",    NULL, toggle_debug },
-		{ "devel",    NULL, do_devel     },
-		{ "help",     NULL, do_help      },
-		{ "version",  NULL, show_version },
+		{ "debug",    NULL, toggle_debug, NULL },
+		{ "devel",    NULL, do_devel,     NULL },
+		{ "help",     NULL, do_help,      NULL },
+		{ "version",  NULL, show_version, NULL },
 
-		{ "list",     NULL, serv_list    },
-		{ "ls",       NULL, serv_list    },
-		{ "enable",   NULL, serv_enable  },
-		{ "disable",  NULL, serv_disable },
-		{ "touch",    NULL, serv_touch   },
-		{ "show",     NULL, serv_show    },
-		{ "edit",     NULL, serv_edit    },
-		{ "create",   NULL, serv_creat   },
-		{ "delete",   NULL, serv_delete  },
-		{ "reload",   NULL, do_reload    },
+		{ "list",     NULL, serv_list,    NULL },
+		{ "ls",       NULL, serv_list,    NULL },
+		{ "enable",   NULL, serv_enable,  NULL },
+		{ "disable",  NULL, serv_disable, NULL },
+		{ "touch",    NULL, serv_touch,   NULL },
+		{ "show",     NULL, serv_show,    NULL },
+		{ "edit",     NULL, serv_edit,    NULL },
+		{ "create",   NULL, serv_creat,   NULL },
+		{ "delete",   NULL, serv_delete,  NULL },
+		{ "reload",   NULL, do_reload,    NULL },
 
-		{ "cond",     cond, NULL         },
+		{ "cond",     cond, NULL, NULL         },
 
-		{ "log",      NULL, do_log       },
-		{ "start",    NULL, do_start     },
-		{ "stop",     NULL, do_stop      },
-		{ "restart",  NULL, do_restart   },
+		{ "log",      NULL, do_log,       NULL },
+		{ "start",    NULL, do_start,     NULL },
+		{ "stop",     NULL, do_stop,      NULL },
+		{ "restart",  NULL, do_restart,   NULL },
 
-		{ "cgroup",   NULL, show_cgroup  },
-		{ "ps",       NULL, show_cgps    },
-		{ "top",      NULL, show_cgtop   },
+		{ "cgroup",   NULL, show_cgroup, &cgrp },
+		{ "ps",       NULL, show_cgps,   &cgrp },
+		{ "top",      NULL, show_cgtop,  &cgrp },
 
-		{ "runlevel", NULL, do_runlevel  },
-		{ "reboot",   NULL, do_reboot    },
-		{ "halt",     NULL, do_halt      },
-		{ "poweroff", NULL, do_poweroff  },
-		{ "suspend",  NULL, do_suspend   },
+		{ "runlevel", NULL, do_runlevel,  NULL },
+		{ "reboot",   NULL, do_reboot,    NULL },
+		{ "halt",     NULL, do_halt,      NULL },
+		{ "poweroff", NULL, do_poweroff,  NULL },
+		{ "suspend",  NULL, do_suspend,   NULL },
 
-		{ "utmp",     NULL, do_utmp      },
-		{ NULL, NULL, NULL }
+		{ "utmp",     NULL, do_utmp,     &utmp },
+		{ NULL, NULL, NULL, NULL }
 	};
 	int interactive = 1, c;
 
 	if (transform(progname(argv[0])))
 		return reboot_main(argc, argv);
 
+	/* Enable functionality depending on system capabilities */
+	cgrp = cgroup_avail();
+	utmp = has_utmp();
+
 	while ((c = getopt_long(argc, argv, "1bcdfh?pqtv", long_options, NULL)) != EOF) {
 		switch(c) {
 		case '1':
@@ -1062,17 +1137,6 @@ int main(int argc, char *argv[])
 	if (interactive)
 		ttinit();
 
-	if (!has_utmp()) {
-		/* system w/o utmp support, disable 'utmp' command */
-		for (c = 0; command[c].cmd; c++) {
-			if (!string_compare(command[c].cmd, "utmp"))
-				continue;
-
-			command[c].cb = NULL;
-			break;
-		}
-	}
-
 	return cmd_parse(argc - optind, &argv[optind], command);
 }
 
