@@ -24,7 +24,11 @@
 #include "config.h"
 #include <stdio.h>
 #include <stdarg.h>
-#include <lite/lite.h>
+#ifdef _LIBITE_LITE
+# include <libite/lite.h>
+#else
+# include <lite/lite.h>
+#endif
 
 #include "finit.h"
 #include "helpers.h"
@@ -32,14 +36,14 @@
 #include "util.h"
 
 static int up       = 0;
-static int loglevel = LOG_NOTICE;
+static int loglevel = LOG_INFO;
 
-void log_init(int dbg)
+void log_init(void)
 {
 	if (debug)
 		loglevel = LOG_DEBUG;
 	else
-		loglevel = LOG_NOTICE;
+		loglevel = LOG_INFO;
 }
 
 /* If we enabled terse mode at boot, restore to previous setting at shutdown */
