@@ -28,7 +28,7 @@
 /*
  * SysV init on Debian/Ubuntu skips these protected mount points
  *
- * It also skips anything below /proc, /sys and /run for good meausre so
+ * It also skips anything below /proc, /sys and /run for good measure so
  * we do the same here.  What we want is a list of non-protected tmpfs
  * and regular filesystems that can be safely unmounted before we do
  * swapoff, and remount / as read-only, respectively.
@@ -36,7 +36,7 @@
 static int is_protected(char *dir)
 {
 	size_t i;
-	char *protected[] = {
+	char *protected_mnts[] = {
 		"/sys", "/proc",
 		"/.dev", "/dev", "/dev/pts", "/dev/shm", "dev/.static/dev", "/dev/vcs",
 		"/run", "/var/run",
@@ -46,8 +46,8 @@ static int is_protected(char *dir)
 		"/proc/", "/sys/", "/run/", NULL
 	};
 
-	for (i = 0; protected[i]; i++) {
-		if (!strcmp(dir, protected[i]))
+	for (i = 0; protected_mnts[i]; i++) {
+		if (!strcmp(dir, protected_mnts[i]))
 			return 1;
 	}
 
@@ -59,46 +59,52 @@ static int is_protected(char *dir)
 	return 0;
 }
 
-static struct mntent *iterator(char *fstab)
+static void iterator_end(FILE **fp)
+{
+	endmntent(*fp);
+	*fp = NULL;
+}
+
+static struct mntent *iterator(char *fstab, FILE **fp)
 {
-	static FILE *fp = NULL;
 	static struct mntent *mnt;
 
-	if (!fp && fstab) {
-		fp = setmntent(fstab, "r");
-		if (!fp)
+	if (!*fp && fstab) {
+		*fp = setmntent(fstab, "r");
+		if (!*fp)
 			return NULL;
 	}
 
-	while ((mnt = getmntent(fp))) {
+	while ((mnt = getmntent(*fp))) {
 		if (is_protected(mnt->mnt_dir))
 			continue;
 
 		return mnt;
 	}
 
-	endmntent(fp);
-	fp = NULL;
-
+	iterator_end(fp);
 	return NULL;
 }
 
 void unmount_tmpfs(void)
 {
 	struct mntent *mnt;
+	FILE *fp = NULL;
 
-	while ((mnt = iterator("/proc/mounts"))) {
-		if (!strcmp("tmpfs", mnt->mnt_fsname))
-			umount(mnt->mnt_dir);
+	while ((mnt = iterator("/proc/mounts", &fp))) {
+		if (!strcmp("tmpfs", mnt->mnt_fsname) && !umount(mnt->mnt_dir))
+			iterator_end(&fp);  /* Restart iteration */
 	}
 }
 
 void unmount_regular(void)
 {
 	struct mntent *mnt;
+	FILE *fp = NULL;
 
-	while ((mnt = iterator("/proc/mounts"))) {
-		umount(mnt->mnt_dir);
+	while ((mnt = iterator("/proc/mounts", &fp))) {
+		if (!umount(mnt->mnt_dir))
+			iterator_end(&fp);  /* Restart iteration */
 	}
 }
 
