@@ -28,7 +28,11 @@
 #include <glob.h>
 #include <stdio.h>
 #include <stdlib.h>
-#include <lite/lite.h>
+#ifdef _LIBITE_LITE
+# include <libite/lite.h>
+#else
+# include <lite/lite.h>
+#endif
 
 #include "initctl.h"
 
