@@ -73,7 +73,11 @@
 #include <string.h>		/* strerror() */
 #include <sys/reboot.h>
 #include <sys/wait.h>
-#include <lite/lite.h>
+#ifdef _LIBITE_LITE
+# include <libite/lite.h>
+#else
+# include <lite/lite.h>
+#endif
 
 #include "finit.h"
 #include "cond.h"
@@ -445,7 +449,7 @@ const char *sig_name(int signo)
 }
 
 /*
- * Inital signal setup - ignore everything but SIGCHLD until we're capable of responding
+ * Initial signal setup - ignore everything but SIGCHLD until we're capable of responding
  */
 static void chld_handler(int sig, siginfo_t *info, void *ctx)
 {
