@@ -28,8 +28,13 @@
 #include <sys/ipc.h>		/* IPC_CREAT */
 #include <sys/resource.h>
 #include <sys/types.h>		/* pid_t */
-#include <lite/lite.h>
-#include <lite/queue.h>		/* BSD sys/queue.h API */
+#ifdef _LIBITE_LITE
+# include <libite/lite.h>
+# include <libite/queue.h>	/* BSD sys/queue.h API */
+#else
+# include <lite/lite.h>
+# include <lite/queue.h>	/* BSD sys/queue.h API */
+#endif
 #include <uev/uev.h>
 
 #include "cgroup.h"
@@ -40,7 +45,7 @@ typedef int svc_cmd_t;
 typedef enum {
 	SVC_TYPE_FREE       = 0,	/* Free to allocate */
 	SVC_TYPE_SERVICE    = 1,	/* Monitored, will be respawned */
-	SVC_TYPE_TASK       = 2,	/* One-shot, runs in parallell */
+	SVC_TYPE_TASK       = 2,	/* One-shot, runs in parallel */
 	SVC_TYPE_RUN        = 4,	/* Like task, but wait for completion */
 	SVC_TYPE_TTY        = 8,	/* Like service, but dedicated to TTYs */
 	SVC_TYPE_SYSV       = 32,	/* SysV style init.d script w/ start/stop */
@@ -70,6 +75,11 @@ typedef enum {
 	SVC_BLOCK_RESTARTING,
 } svc_block_t;
 
+typedef enum {
+	SVC_ONCRASH_IGNORE = 0,
+	SVC_ONCRASH_REBOOT = 1,
+} svc_oncrash_action_t;
+
 #define MAX_ID_LEN       16
 #define MAX_ARG_LEN      64
 #define MAX_IDENT_LEN    (MAX_ARG_LEN + MAX_ID_LEN + 1)
@@ -102,7 +112,7 @@ typedef struct svc {
 	struct cgroup  cgroup;
 
 	/* Service details */
-	int            sighalt;        /* Signal to stop prorcess, default: SIGTERM */
+	int            sighalt;        /* Signal to stop process, default: SIGTERM */
 	int            killdelay;      /* Delay in msec before sending SIGKILL */
 	pid_t          oldpid, pid;
 	char           pidfile[256];
@@ -127,6 +137,10 @@ typedef struct svc {
 
 	/* Counters */
 	char           once;	       /* run/task, (at least) once per runlevel */
+	unsigned int   restart_tot;    /* Total restarts ever, summarized, including `initctl restart` */
+	unsigned char  restart_max;    /* Maximum number of restarts allowed */
+	int            restart_tmo;    /* Time required for the service to start. */
+	unsigned char  oncrash_action; /* Action to perform in crashed state. */
 	char           respawn;	       /* ttys, or services with `respawn`, never increment restart_cnt */
 	const char     restart_cnt;    /* Incremented for each restart by service monitor. */
 
@@ -207,7 +221,6 @@ void	    svc_prune_bootstrap	   (void);
 
 void        svc_enable             (svc_t *svc);
 int         svc_enabled            (svc_t *svc);
-int         svc_is_unique          (svc_t *svc);
 
 int         svc_parse_jobstr       (char *str, size_t len, int (*found)(svc_t *), int (not_found)(char *, char *));
 
