@@ -24,6 +24,7 @@
 #include "config.h"
 #include <ctype.h>		/* isprint() */
 #include <errno.h>
+#include <mntent.h>
 #include <regex.h>
 #include <string.h>
 #include <stdlib.h>
@@ -37,7 +38,11 @@
 # include <sys/ioctl.h>
 #endif
 #include <sys/sysinfo.h>	/* sysinfo() */
-#include <lite/lite.h>		/* strlcat() */
+#ifdef _LIBITE_LITE
+# include <libite/lite.h>
+#else
+# include <lite/lite.h>
+#endif
 #include "util.h"
 
 #ifdef HAVE_TERMIOS_H
@@ -177,7 +182,8 @@ int fnread(char *buf, size_t len, char *fmt, ...)
 	if (!fp)
 		return -1;
 
-	len = fread(buf, sizeof(char), len, fp);
+	len = fread(buf, sizeof(char), len - 1, fp);
+	buf[len] = 0;
 	fclose(fp);
 
 	return (int)len;
@@ -216,7 +222,7 @@ int fnwrite(char *value, char *fmt, ...)
 
 int fngetint(char *path, int *val)
 {
-	char buf[10];
+	char buf[64];
 
 	if (fnread(buf, sizeof(buf), path) <= 0)
 		return -1;
@@ -393,6 +399,55 @@ char *sanitize(char *arg, size_t len)
 	return arg;
 }
 
+static int hasopt(char *opts, char *opt)
+{
+	char buf[strlen(opts) + 1];
+	char *ptr;
+
+	memcpy(buf, opts, sizeof(buf));
+	ptr = strtok(buf, ",");
+	while (ptr) {
+		if (!strcmp(ptr, opt))
+			return 1;
+
+		ptr = strtok(NULL, ",");
+	}
+
+	return 0;
+}
+
+int ismnt(char *file, char *dir, char *mode)
+{
+	struct mntent *mnt;
+	int found = 0;
+	FILE *fp;
+
+	fp = setmntent(file, "r");
+	if (!fp)
+		return 0;	/* Dunno, maybe not */
+
+	while ((mnt = getmntent(fp))) {
+		if (!strcmp(mnt->mnt_dir, dir)) {
+			if (mode) {
+				if (hasopt(mnt->mnt_opts, mode))
+					found = 1;
+			} else
+				found = 1;
+
+			break;
+		}
+	}
+	endmntent(fp);
+
+	return found;
+}
+
+/* Requires /proc to be mounted */
+int fismnt(char *dir)
+{
+	return ismnt("/proc/mounts", dir, NULL);
+}
+
 #ifdef HAVE_TERMIOS_H
 /*
  * Called by initctl, and by finit at boot and shutdown, to
