@@ -32,7 +32,6 @@
 #include <sys/reboot.h>
 #include <termios.h>
 #endif
-#include <lite/lite.h>
 
 #ifndef RB_SW_SUSPEND /* Since Linux 2.5.18, but not in GLIBC until 2.19 */
 #define RB_SW_SUSPEND	0xd000fce2
@@ -45,7 +44,13 @@ extern char *prognm;
 
 /* Define for printheader() from conio.h, used in initctl */
 #define SCREEN_WIDTH ttcols
-#include <lite/conio.h>
+#ifdef _LIBITE_LITE
+# include <libite/conio.h>
+# include <libite/lite.h>
+#else
+# include <lite/conio.h>
+# include <lite/lite.h>
+#endif
 
 char *progname     (char *arg0);
 
@@ -65,6 +70,9 @@ char *memsz        (uint64_t sz, char *buf, size_t len);
 
 char *sanitize     (char *arg, size_t len);
 
+int   ismnt        (char *file, char *dir, char *mode);
+int   fismnt       (char *dir);
+
 #ifdef HAVE_TERMIOS_H
 int     ttinit     (void);
 int     ttraw      (void);
