@@ -26,7 +26,11 @@
 #include <time.h>
 #include <arpa/inet.h>
 #include <sys/utsname.h>
-#include <lite/lite.h>
+#ifdef _LIBITE_LITE
+# include <libite/lite.h>
+#else
+# include <lite/lite.h>
+#endif
 
 #include "helpers.h"
 #include "util.h"
